=================================================
Cirrocumulus for Single-Cell Data Visualization
=================================================

Cirrocumulus is an interactive visualizer on large-scale single-cell genomics data, with the following key features:

* Run on Google App Engine (see `here <https://cirrocumulus.appspot.com>`_), or on your local machine;
* Scale to > 6 million cells on commodity hardware;
* Share datasets with collaborators;
* Interactively create and share cell annotations;
* Explore multiple features and embeddings simultaneously;
* Visualize 3D embeddings. 